@@ -13,12 +13,23 @@ from ioc.requirement import NOT_PROVIDED
 from ioc.requirement import NO_DEFAULT
 from ioc.exc import UnsatisfiedDependency
 from ioc.exc import MissingDependencies
+from ioc.pkg import setup
 from ioc.provider import get_unsatisfied_dependencies
 
 
 __version__ = '1.3.11'
 
 
+__all__ = [
+    'inject',
+    'is_satisfied',
+    'provide',
+    'require',
+    'setup',
+    'teardown',
+]
+
+
 def require(names, *args, **kwargs):
     req = provider.get_requirement(names)
     if req is not None:
